==> kubernetes-model-flowcontrol-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitedPriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LimitedPriorityLevelConfigurationFluent<A extends LimitedPriorityLevelConfigurationFluent<A>> extends Fluent<A>{
  public Integer getBorrowingLimitPercent();
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent);
  public Boolean hasBorrowingLimitPercent();
  public Integer getLendablePercent();
  public A withLendablePercent(Integer lendablePercent);
  public Boolean hasLendablePercent();
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse();
  public LimitResponse buildLimitResponse();
  public A withLimitResponse(LimitResponse limitResponse);
  public Boolean hasLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item);
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item);
  public Integer getNominalConcurrencyShares();
  public A withNominalConcurrencyShares(Integer nominalConcurrencyShares);
  public Boolean hasNominalConcurrencyShares();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LimitResponseNested<N> extends Nested<N>,LimitResponseFluent<LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>>{
    public N and();
    public N endLimitResponse();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitedPriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LimitedPriorityLevelConfigurationFluent<A extends LimitedPriorityLevelConfigurationFluent<A>> extends Fluent<A>{
  public Integer getBorrowingLimitPercent();
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent);
  public Boolean hasBorrowingLimitPercent();
  public Integer getLendablePercent();
  public A withLendablePercent(Integer lendablePercent);
  public Boolean hasLendablePercent();
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse();
  public LimitResponse buildLimitResponse();
  public A withLimitResponse(LimitResponse limitResponse);
  public Boolean hasLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item);
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponse();
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item);
  public Integer getNominalConcurrencyShares();
  public A withNominalConcurrencyShares(Integer nominalConcurrencyShares);
  public Boolean hasNominalConcurrencyShares();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LimitResponseNested<N> extends Nested<N>,LimitResponseFluent<LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>>{
    public N and();
    public N endLimitResponse();
    
  }
  
}
